@@ -200,7 +200,7 @@ class cut(StrOp):
             * a string containing a comma separated list of int
             * None (default value) for all columns
 
-        not_present_value (str): A string to display when requesting a column that does not exist
+        default (str): A string to display when requesting a column that does not exist
 
     Returns:
         A string, a list of strings or a list of list of strings
@@ -212,7 +212,7 @@ class cut(StrOp):
         ['col1', 'col2', 'col3']
         >>> s | cut(col=1)
         'col2'
-        >>> s | cut(col='1,2,10',not_present_value='N/A')
+        >>> s | cut(col='1,2,10',default='N/A')
         ['col2', 'col3', 'N/A']
         >>> s='col1.1 col1.2 col1.3\ncol2.1 col2.2 col2.3'
         >>> s | cut()
@@ -229,28 +229,36 @@ class cut(StrOp):
         >>> s | cut(sep=' | ')
         [['col1.1', 'col1.2', ' col1.3'], ['col2.1', 'col2.2', 'col2.3']]
     """
+    sep_is_regex = False
+    flags = 0
+
     @classmethod
     def split(cls, text, sep, *args,**kwargs):
         return text.split(sep)
 
     @classmethod
-    def fn(cls, text, sep=None, col=None, not_present_value='', *args,**kwargs):
+    def fn(cls, text, sep=None, col=None, default='', *args,**kwargs):
+        if cls.sep_is_regex:
+            if isinstance(sep, basestring):
+                sep = re.compile(sep,cls.flags)
         if isinstance(col, basestring):
             col = [int(i) for i in col.split(',')]
         if isinstance(col,(list,tuple)):
             nbcol = len(col)
             line_cols = cls.split(text,sep, *args,**kwargs)
             nblinecol = len(line_cols)
-            return [ line_cols[c] if c < nblinecol else not_present_value for c in col ]
+            return [ line_cols[c] if c < nblinecol else default for c in col ]
         else:
             line_cols = cls.split(text,sep, *args,**kwargs)
+            if line_cols is None:
+                return default
             nblinecol = len(line_cols)
             if col == None:
                 return line_cols
             elif col < nblinecol:
                 return line_cols[col]
             else:
-                return not_present_value
+                return default
 
 class cutre(cut):
     r""" Extract columns from a string or a list of strings with re.split()
@@ -273,7 +281,7 @@ class cutre(cut):
             * a string containing a comma separated list of int
             * None (default value) for all columns
 
-        not_present_value (str): A string to display when requesting a column that does not exist
+        default (str): A string to display when requesting a column that does not exist
 
     Returns:
         A string, a list of strings or a list of list of strings
@@ -294,16 +302,17 @@ class cutre(cut):
         >>> s | cutre(mysep)
         [['col1.1', 'col1.2', 'col1.3'], ['col2.1', 'col2.2', 'col2.3']]
     """
+    sep_is_regex = True
+
     @classmethod
     def split(cls, text, sep, *args,**kwargs):
-        if hasattr(sep,'match'):
-            return sep.split(text)
-        return re.split(sep,text)
+        return sep.split(text)
 
 class cutca(cut):
     r""" Extract columns from a string or a list of strings through pattern capture
 
     This works like :class:`textops.cutre` except it needs a pattern having parenthesis to capture column.
+    It uses :func:`re.match` for capture, this means the pattern must start at line beginning.
 
         * if the input is a simple string, cutca() will return a list of strings
           representing the splitted input string.
@@ -321,10 +330,10 @@ class cutca(cut):
             * a string containing a comma separated list of int
             * None (default value) for all columns
 
-        not_present_value (str): A string to display when requesting a column that does not exist
+        default (str): A string to display when requesting a column that does not exist
 
     Returns:
-        A string, a list of strings or a list of list of strings
+        a list of strings or a list of list of strings
 
     Examples:
 
@@ -335,14 +344,171 @@ class cutca(cut):
         >>> s | cutca(r'[^-]*-([^-]*)-[^=]*=([^=]*)=[^_]*_([^_]*)_','0,2,4','not present')
         [['col1', 'col3', 'not present'], ['col11', 'col33', 'not present']]
     """
+    sep_is_regex = True
+
     @classmethod
     def split(cls, text, sep, *args,**kwargs):
-        if hasattr(sep,'match'):
-            m = sep.match(text)
-        else:
-            m = re.match(sep,text)
+        m = sep.match(text)
         return m.groups() if m else []
 
+class cutm(cut):
+    r""" Extract exactly one column by using :func:`re.match`
+
+    This is a shortcut for ``cutca('mypattern',col=0)``
+
+        * if the input is a simple string, :class:`textops.cutm` will return a strings
+          representing the captured substring.
+        * if the input is a list of strings or a string with newlines, :class:`textops.cutm` will
+          return a list of captured substring.
+
+    Args:
+        sep (str or re.RegexObject): a regular expression string or object having capture parenthesis
+        col (int or list of int or str) : specify one or many columns you want to get back,
+            You can specify :
+
+            * an int as a single column number (starting with 0)
+            * a list of int as the list of colmun
+            * a string containing a comma separated list of int
+            * None (default value) for all columns
+
+        default (str): A string to display when requesting a column that does not exist
+
+    Returns:
+        a list of strings or a list of list of strings
+
+    Examples:
+
+        >>> s='-col1- =col2= _col3_'
+        >>> s | cutm(r'[^-]*-([^-]*)-')
+        'col1'
+        >>> s=['-col1- =col2= _col3_','-col11- =col22= _col33_']
+        >>> s | cutm(r'[^-]*-([^-]*)-')
+        ['col1', 'col11']
+        >>> s | cutm(r'[^-]*-(badpattern)-',default='-')
+        ['-', '-']
+    """
+    sep_is_regex = True
+
+    @classmethod
+    def split(cls, text, sep, *args,**kwargs):
+        m = sep.match(text)
+        return m.groups()[0] if m else None
+
+class cutmi(cutm):
+    r""" Extract exactly one column by using :func:`re.match` (case insensitive)
+
+    This works like :class:`textops.cutm` except it is caseinsensitive.
+
+        * if the input is a simple string, :class:`textops.cutmi` will return a strings
+          representing the captured substring.
+        * if the input is a list of strings or a string with newlines, :class:`textops.cutmi` will
+          return a list of captured substring.
+
+    Args:
+        sep (str or re.RegexObject): a regular expression string or object having capture parenthesis
+        col (int or list of int or str) : specify one or many columns you want to get back,
+            You can specify :
+
+            * an int as a single column number (starting with 0)
+            * a list of int as the list of colmun
+            * a string containing a comma separated list of int
+            * None (default value) for all columns
+
+        default (str): A string to display when requesting a column that does not exist
+
+    Returns:
+        a list of strings or a list of list of strings
+
+    Examples:
+
+        >>> s='-col1- =col2= _col3_'
+        >>> s | cutm(r'.*(COL\d+)',default='no found')
+        'no found'
+        >>> s='-col1- =col2= _col3_'
+        >>> s | cutmi(r'.*(COL\d+)',default='no found')
+        'col3'
+    """
+    flags = re.IGNORECASE
+
+class cuts(cut):
+    r""" Extract exactly one column by using :func:`re.search`
+
+    This works like :class:`textops.cutm` except it searches the first occurence of the pattern in
+    the string.
+
+        * if the input is a simple string, :class:`textops.cuts` will return a strings
+          representing the captured substring.
+        * if the input is a list of strings or a string with newlines, :class:`textops.cuts` will
+          return a list of captured substring.
+
+    Args:
+        sep (str or re.RegexObject): a regular expression string or object having capture parenthesis
+        col (int or list of int or str) : specify one or many columns you want to get back,
+            You can specify :
+
+            * an int as a single column number (starting with 0)
+            * a list of int as the list of colmun
+            * a string containing a comma separated list of int
+            * None (default value) for all columns
+
+        default (str): A string to display when requesting a column that does not exist
+
+    Returns:
+        a list of strings or a list of list of strings
+
+    Examples:
+
+        >>> s='-col1- =col2= _col3_'
+        >>> s | cuts(r'_([^_]*)_')
+        'col3'
+        >>> s=['-col1- =col2= _col3_','-col11- =col22= _col33_']
+        >>> s | cuts(r'_([^_]*)_')
+        ['col3', 'col33']
+    """
+    sep_is_regex = True
+
+    @classmethod
+    def split(cls, text, sep, *args,**kwargs):
+        m = sep.search(text)
+        return m.groups()[0] if m else None
+
+class cutsi(cuts):
+    r""" Extract exactly one column by using :func:`re.search`
+
+    This works like :class:`textops.cutm` except it searches the first occurence of the pattern in
+    the string.
+
+        * if the input is a simple string, :class:`textops.cutsi` will return a strings
+          representing the captured substring.
+        * if the input is a list of strings or a string with newlines, :class:`textops.cutsi` will
+          return a list of captured substring.
+
+    Args:
+        sep (str or re.RegexObject): a regular expression string or object having capture parenthesis
+        col (int or list of int or str) : specify one or many columns you want to get back,
+            You can specify :
+
+            * an int as a single column number (starting with 0)
+            * a list of int as the list of colmun
+            * a string containing a comma separated list of int
+            * None (default value) for all columns
+
+        default (str): A string to display when requesting a column that does not exist
+
+    Returns:
+        a list of strings or a list of list of strings
+
+    Examples:
+
+        >>> s='-col1- =col2= _col3_'
+        >>> s | cuts(r'_(COL[^_]*)_')
+        ''
+        >>> s='-col1- =col2= _col3_'
+        >>> s | cutsi(r'_(COL[^_]*)_')
+        'col3'
+    """
+    flags = re.IGNORECASE
+
 class cutdct(cut):
     r""" Extract columns from a string or a list of strings through pattern capture
 
@@ -365,7 +531,7 @@ class cutdct(cut):
             * a string containing a comma separated list of int
             * None (default value) for all columns
 
-        not_present_value (str): A string to display when requesting a column that does not exist
+        default (str): A string to display when requesting a column that does not exist
 
     Returns:
         A string, a list of strings or a list of list of strings
@@ -380,12 +546,11 @@ class cutdct(cut):
         [{'item': 'col1', 'i_price': 'col3', 'i_count': 'col2'},...
         {'item': 'col11', 'i_price': 'col33', 'i_count': 'col22'}]
     """
+    sep_is_regex = True
+
     @classmethod
     def split(cls, text, sep, *args,**kwargs):
-        if hasattr(sep,'match'):
-            m = sep.match(text)
-        else:
-            m = re.match(sep,text)
+        m = sep.match(text)
         return m.groupdict() if m else {}
 
 class cutkv(cut):
@@ -419,13 +584,12 @@ class cutkv(cut):
         {'col11': {'item': 'col11', 'i_price': 'col33', 'i_count': 'col22'}}]
 
     """
+    sep_is_regex = True
+
     @classmethod
     def split(cls, text, sep, key_name = 'key', *args,**kwargs):
         # Use named 'key_name' parameter, not postionnal
-        if hasattr(sep,'match'):
-            m = sep.match(text)
-        else:
-            m = re.match(sep,text)
+        m = sep.match(text)
         if m:
             dct = m.groupdict()
             kv = dct.get(key_name)
